/* License
 * 
 * Copyright 1994-2004 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *  
 *  * Redistribution of source code must retain the above copyright notice,
 *	this list of conditions and the following disclaimer.
 * 
 *  * Redistribution in binary form must reproduce the above copyright notice,
 *	this list of conditions and the following disclaimer in the
 *	documentation and/or other materials provided with the distribution.
 * 
 * Neither the name of Sun Microsystems, Inc. or the names of contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 *  
 * This software is provided "AS IS," without a warranty of any kind. ALL
 * EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING
 * ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
 * OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN MICROSYSTEMS, INC. ("SUN")
 * AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 * AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS
 * DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE FOR ANY LOST
 * REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL,
 * INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY
 * OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE,
 * EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *  
 * You acknowledge that this software is not designed, licensed or intended
 * for use in the design, construction, operation or maintenance of any
 * nuclear facility. 
 */

//package net.mpowers.telnet;

import java.io.InputStream;
import java.io.DataInputStream;
import java.io.OutputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import javax.microedition.io.StreamConnection;

/**
* Wraps a StreamConnection to properly interpret 
* telnet negotiation commands and options.
*/
public class TelnetConnection implements StreamConnection
{
    protected StreamConnection source;
    private InputStream input;
    private OutputStream output;
    private int width, height;
    private String terminal;

    /**
    * Constructor specifying the StreamConnection to wrap.
    */ 
    public TelnetConnection( StreamConnection inConnection )
    {
        this( inConnection, 0, 0, null );
    }
    
    /**
    * Constructor specifying the StreamConnection to wrap,
    * plus optional terminal emulation settings.
    */ 
    public TelnetConnection( StreamConnection inConnection,
        int inWidth, int inHeight, String inTermType )
    {
        source = inConnection;
        input = null;
        output = null;
        width = inWidth;
        height = inHeight;
        terminal = inTermType;
    }
    
    private OutputStream getOutputStream() throws IOException
    {
        if ( output == null )
        {
            output = source.openOutputStream();
        }
        return output;
    }
    
    public InputStream openInputStream() 
        throws IOException
    {
        input = source.openInputStream();
        output = getOutputStream();
        return new TelnetInputStream( 
            input, output, width, height, terminal );
    }
    
    public DataInputStream openDataInputStream() 
        throws IOException
    {
        return new DataInputStream( openInputStream() );
    }

    public OutputStream openOutputStream() 
        throws IOException
    {
        return new TelnetOutputStream( getOutputStream() );
    }
    
    public DataOutputStream openDataOutputStream() 
        throws IOException
    {
        return new DataOutputStream( openOutputStream() );
    }
    
    public void close() throws IOException
    {
        source.close();
    }

}
